<?php
/**
 * Gutenify Magazine: Block Patterns
 *
 * @since Gutenify Magazine 1.0
 */

 /**
  * Get patterns content.
  *
  * @param string $file_name Filename.
  * @return string
  */
function gutenify_magazine_get_pattern_content( $file_name ) {
	ob_start();
	include get_theme_file_path( '/inc/patterns/' . $file_name . '.php' );
	$output = ob_get_contents();
	ob_end_clean();
	return $output;
}

/**
 * Registers block patterns and categories.
 *
 * @since Gutenify Magazine 1.0
 *
 * @return void
 */
function gutenify_magazine_register_block_patterns() {

	$patterns = array(
		'header-default' => array(
			'title'      => __( 'Default header', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'header-two' => array(
			'title'      => __( 'Header Two ', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'header-three' => array(
			'title'      => __( 'Header Three', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'header-four' => array(
			'title'      => __( 'Header Four', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'header-five' => array(
			'title'      => __( 'Header Five', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'header-dark' => array(
			'title'      => __( 'Header Dark', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'footer-default' => array(
			'title'      => __( 'Default footer', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-footers' ),
			'blockTypes' => array( 'core/template-part/footer' ),
		),
		'footer-light' => array(
			'title'      => __( 'Footer Light', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-footers' ),
			'blockTypes' => array( 'core/template-part/footer' ),
		),
		'primary-sidebar' => array(
			'title'    => __( 'Primary Sidebar', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-sidebars' ),
		),
		'hidden-404' => array(
			'title'    => __( '404 content', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-pages' ),
		),
		'post-listing-single-column' => array(
			'title'    => __( 'Post Single Column', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'post-listing-two-column' => array(
			'title'    => __( 'Post Two Column', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'post-listing-three-column' => array(
			'title'    => __( 'Post Three Column', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'post-listing-four-column' => array(
			'title'    => __( 'Post Four Column', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'post-listing-hidden-content' => array(
			'title'    => __( 'Post Lists', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'feature-post-column' => array(
			'title'    => __( 'Feature Post Column', 'gutenify-magazine' ),
			//'inserter' => false,
			'categories' => array( 'gutenify-magazine-query' ),
		),
		'comment-section-1' => array(
			'title'    => __( 'Comment Section 1', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-comment-sections' ),
		),
		'advertisement-banner' => array(
			'title'    => __( 'Advertisement Banner', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-advertisement-banner' ),
		),
		'section-title' => array(
			'title'    => __( 'Section Title', 'gutenify-magazine' ),
			'categories' => array( 'gutenify-magazine-section-title' ),
		),
	);

	$block_pattern_categories = array(
		'gutenify-magazine-footers' => array( 'label' => __( 'Footers', 'gutenify-magazine' ) ),
		'gutenify-magazine-headers' => array( 'label' => __( 'Headers', 'gutenify-magazine' ) ),
		'gutenify-magazine-query'   => array( 'label' => __( 'Query', 'gutenify-magazine' ) ),
		'gutenify-magazine-sidebars'   => array( 'label' => __( 'Sidebars', 'gutenify-magazine' ) ),
		'gutenify-magazine-pages'   => array( 'label' => __( 'Pages', 'gutenify-magazine' ) ),
		'gutenify-magazine-comment-section'   => array( 'label' => __( 'Comment Sections', 'gutenify-magazine' ) ),
		'gutenify-magazine-advertisement-banner'   => array( 'label' => __( 'Banner Sections', 'gutenify-magazine' ) ),
		'gutenify-magazine-section-title'          => array( 'label' => __( 'Section Title', 'gutenify-magazine' ) ),

	);

	/**
	 * Filters the theme block pattern categories.
	 *
	 * @since Gutenify Magazine 1.0
	 *
	 * @param array[] $block_pattern_categories {
	 *     An associative array of block pattern categories, keyed by category name.
	 *
	 *     @type array[] $properties {
	 *         An array of block category properties.
	 *
	 *         @type string $label A human-readable label for the pattern category.
	 *     }
	 * }
	 */
	$block_pattern_categories = apply_filters( 'gutenify_magazine_block_pattern_categories', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}

	/**
	 * Filters the theme block patterns.
	 *
	 * @since Gutenify Magazine 1.0
	 *
	 * @param array $block_patterns List of block patterns by name.
	 */
	$patterns = apply_filters( 'gutenify_magazine_block_patterns', $patterns );

	foreach ( $patterns as $block_pattern => $pattern ) {
		$pattern['content'] = gutenify_magazine_get_pattern_content( $block_pattern );
		register_block_pattern(
			'gutenify-magazine/' . $block_pattern,
			$pattern
		);
	}
}
add_action( 'init', 'gutenify_magazine_register_block_patterns', 9 );
